@@ -566,7 +566,7 @@ on_entry_pref_database_name_changed    (GtkEditable     *editable,
 
 
 void
-on_fileentry_database_socket_changed   (GtkEditable     *editable,
+on_fileentry_database_socket_file_set   (GtkFileChooserButton     *editable,
                                         gpointer         user_data)
 {
 	pref_database_socket_changed_cb (editable);
