@@ -92,8 +92,7 @@ druid_finish_clicked (GnomeDruidPage *druidpage, GtkWidget *druid)
 				NULL) == TRUE)
 	{
 		w = lookup_widget (druid, "fileentry_druid_socket");
-		s = gnome_file_entry_get_full_path (	GNOME_FILE_ENTRY (w),
-							FALSE);
+		s = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (w));
 		gconf_client_set_string (schedwi_gconf,
 					GCONF_PATH "/database/socket",
 					s,
@@ -200,7 +199,7 @@ dialog_druid_build (GtkWidget *main_window)
 				NULL);
 	if (v != NULL) {
 		w = lookup_widget (main_window, "fileentry_druid_socket");
-		gnome_file_entry_set_filename (	GNOME_FILE_ENTRY (w),
+		gtk_file_chooser_set_filename (	GTK_FILE_CHOOSER (w),
 						gconf_value_get_string (v));
 		gconf_value_free (v);
 	}
