@@ -1,27 +1,27 @@
 /* Schedwi
    Copyright (C) 2007 Herve Quatremain
 
-   This program is free software; you can redistribute it and/or modify
+   This file is part of Schedwi.
+
+   Schedwi is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   Schedwi is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* env_window_cb.c - GUI functions for the environment window */
 
 #include <schedwi.h>
 
-#include "support.h"
-#include "interface.h"
+#include <schedwi_interface.h>
 
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
