@@ -51,11 +51,13 @@ error_window (const char *primary_text, const char *error_message)
 					error_message);
 		}
 	}
-	dialog_error = gtk_message_dialog_new_with_markup (NULL,
+	dialog_error = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_OK,
-						(markup == NULL) ? "": markup);
+						NULL);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog_error),
+					(markup == NULL) ? "": markup);
 	gtk_dialog_run (GTK_DIALOG (dialog_error));
 	gtk_widget_destroy (dialog_error);
 	g_free (markup);
@@ -125,11 +127,13 @@ info_window (const char *primary_text, const char *info_message)
 					info_message);
 		}
 	}
-	dialog_info = gtk_message_dialog_new_with_markup (NULL,
+	dialog_info = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_INFO,
 						GTK_BUTTONS_OK,
-						(markup == NULL) ? "": markup);
+						NULL);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog_info),
+					(markup == NULL) ? "": markup);
 	gtk_dialog_run (GTK_DIALOG (dialog_info));
 	gtk_widget_destroy (dialog_info);
 	g_free (markup);
@@ -164,11 +168,13 @@ warning_window (const char *primary_text, const char *warning_message)
 					warning_message);
 		}
 	}
-	dialog_warning = gtk_message_dialog_new_with_markup (NULL,
+	dialog_warning = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_DESTROY_WITH_PARENT,
 						GTK_MESSAGE_WARNING,
 						GTK_BUTTONS_OK,
-						(markup == NULL) ? "": markup);
+						NULL);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog_warning),
+					(markup == NULL) ? "": markup);
 	gtk_dialog_run (GTK_DIALOG (dialog_warning));
 	gtk_widget_destroy (dialog_warning);
 	g_free (markup);
@@ -193,12 +199,13 @@ question_delete_window (GtkWidget *parent, const char *message)
 			"<span weight=\"bold\" size=\"larger\">%s</span>",
 			message);
 
-	dialog = gtk_message_dialog_new_with_markup (
+	dialog = gtk_message_dialog_new (
 					GTK_WINDOW (parent),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
 					GTK_BUTTONS_NONE,
-					markup);
+					NULL);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
 	
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL,
@@ -244,12 +251,13 @@ question_replace_window (	GtkWidget *parent,
 			primary_text, secondary_text);
 	}
 
-	dialog = gtk_message_dialog_new_with_markup (
+	dialog = gtk_message_dialog_new (
 					GTK_WINDOW (parent),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
 					GTK_BUTTONS_NONE,
-					markup);
+					NULL);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
 	
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL,
@@ -295,12 +303,13 @@ question_window (	GtkWidget *parent,
 			primary_text, secondary_text);
 	}
 
-	dialog = gtk_message_dialog_new_with_markup (
+	dialog = gtk_message_dialog_new (
 					GTK_WINDOW (parent),
 					GTK_DIALOG_DESTROY_WITH_PARENT,
 					GTK_MESSAGE_QUESTION,
 					GTK_BUTTONS_YES_NO,
-					markup);
+					NULL);
+	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), markup);
 	ret = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 	g_free (markup);
