@@ -505,9 +505,9 @@ pref_database_database_changed_cb (GtkEntry *entry)
 }
 
 void
-pref_database_socket_changed_cb (GtkEditable *editable)
+pref_database_socket_changed_cb (GtkFileChooserButton *editable)
 {
-	gchar *s;
+	gchar *s = NULL;
 
 	if (	   schedwi_gconf != NULL
 		&& gconf_client_key_is_writable (
@@ -515,14 +515,14 @@ pref_database_socket_changed_cb (GtkEditable *editable)
 				GCONF_PATH "/database/socket",
 				NULL) == TRUE)
 	{
-		s = gtk_editable_get_chars (editable, 0, -1);
+		s = gtk_file_chooser_get_filename (
+						GTK_FILE_CHOOSER (editable));
 		if (s != NULL) {
 			gconf_client_set_string (
 				schedwi_gconf,
 				GCONF_PATH "/database/socket",
 				s,
 				NULL);
-			g_free (s);
 		}
 	}
 }
@@ -612,7 +612,7 @@ pref_database_restore_activated_cb (GtkButton *button)
 		{
 			w = lookup_widget (	widget,
 						"fileentry_database_socket");
-			gnome_file_entry_set_filename (GNOME_FILE_ENTRY (w),
+			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (w),
 						ptr->socket_file);
 			gconf_client_set_string (schedwi_gconf,
 						GCONF_PATH "/database/socket",
@@ -771,7 +771,7 @@ init_pref (GtkWidget *widget)
 
 	w = lookup_widget (widget, "fileentry_database_socket");
 	if (ptr->socket_file != NULL) {
-		gnome_file_entry_set_filename (	GNOME_FILE_ENTRY (w),
+		gtk_file_chooser_set_filename (	GTK_FILE_CHOOSER (w),
 						ptr->socket_file);
 	}
 	gtk_widget_set_sensitive (w, gconf_client_key_is_writable (
