@@ -38,7 +38,7 @@ extern void pref_database_host_changed_cb OF((GtkEntry *entry));
 extern void pref_database_user_changed_cb OF((GtkEntry *entry));
 extern void pref_database_database_changed_cb OF((GtkEntry *entry));
 extern void pref_database_port_changed_cb OF((GtkSpinButton *spin));
-extern void pref_database_socket_changed_cb OF((GtkEditable *editable));
+extern void pref_database_socket_changed_cb OF((GtkFileChooserButton *editable));
 extern void pref_grid_line_style_changed_cb OF((GtkComboBox *combo_box));
 extern void pref_grid_color_set_cb OF((GtkColorButton *color_button));
 extern void pref_grid_ratio_clicked OF((GtkButton *button));
