@@ -289,6 +289,7 @@ clean_process ()
 {
 #if HAVE_CHDIR
 	char *tmp;
+	int foo;
 #endif
 
 	/* Change to a temporary directory */
@@ -304,9 +305,13 @@ clean_process ()
 #endif /* HAVE_GETENV */
 	if (tmp == NULL) {
 #ifdef P_tmpdir
-		chdir (P_tmpdir);
+		/*
+		 * We don't care the return value of chdir.  This is to avoid
+		 * warnings from the compiler about unused result.
+		 */
+		foo = chdir (P_tmpdir);
 #else
-		chdir ("/tmp");
+		foo = chdir ("/tmp");
 #endif
 	}
 #endif /* HAVE_CHDIR */
@@ -408,7 +413,13 @@ write_pid_file (const char *file_name)
 	/* Write the PID to the file */
 	l = snprintf (pid_str, 26, "%ld\n", (long int)getpid ());
 	pid_str [26 - 1] = '\0';
-	write (fd_pid_file, pid_str, schedwi_strlen (pid_str));
+	/*
+	 * We don't care the return value of write.  This is to avoid
+	 * warnings from the compiler about unused result.
+	 */
+	if (write (fd_pid_file, pid_str, schedwi_strlen (pid_str)) > 0) {
+		return 0;
+	}
 	return 0;
 }
 
